@@ -32,7 +32,7 @@ def define_connection(cls, from_port, to_port):
 class Port(object):
     """A class that represents an input or output port on a task."""
 
-    def __init__(self, name, task, optional=False, value=None, action=None):
+    def __init__(self, name, task, optional=False, value=None, action=None, constant=False):
         """Constructor."""
         self.name=name
         self.task=task
@@ -41,6 +41,7 @@ class Port(object):
         else:
             self.action = action
         self.optional=optional
+        self.constant=constant
         self.input_connections = []
         self.output_connections = []
         self.set_value(value)
@@ -124,6 +125,7 @@ class Port(object):
         tmp['Name'] = self.name
         tmp['Task'] = str(self.task.id)
         tmp['Optional'] = str(self.optional)
+        tmp['Constant'] = str(self.constant)
         tmp['Value'] = str(self.value)
         tmp['Ready'] = str(self.ready())
         tmp['Action'] = self.action
@@ -137,10 +139,10 @@ class Port(object):
         return tmp
 
     def __repr__(self):
-        return str(self)
+        return str(self)    #pragma:nocover
 
     def __str__(self, indentation=""):
-        return pprint.pformat(self._repn_(), 2)
+        return pprint.pformat(self._repn_(), 2) #pragma:nocover
 
     def ready(self):
         if not self.value is None:
@@ -148,7 +150,6 @@ class Port(object):
         if len(self.input_connections) == 0:
             return self._ready
         if self.action == 'store':
-            #print 'x', self.name, self.input_connections[0].from_port.task.id, self.input_connections[0].from_port.task.name, self.input_connections[0].ready()
             return self.input_connections[0].ready()
         elif self.action in ['append_any', 'map_any', 'store_any']:
             for connection in self.input_connections:
@@ -160,7 +161,10 @@ class Port(object):
                 if not connection.ready():
                     return False
             return True
-        return True
+        #
+        # We should never get here.
+        #
+        raise IOError, "WARNING: unknown action: "+self.action  #pragma:nocover
 
     def set_ready(self):
         self._ready=True
@@ -180,9 +184,9 @@ class Ports(dict):
         """Set the name of this class instance."""
         self._name_ = name
 
-    def declare(self, name, optional=False, action=None):
+    def declare(self, name, optional=False, action=None, constant=False):
         """Declare a port."""
-        port = Port(name, self._task, optional=optional, action=action)
+        port = Port(name, self._task, optional=optional, action=action, constant=constant)
         setattr(self, name, port)
         return port
 
@@ -246,7 +250,7 @@ class Ports(dict):
         return tmp
         
 
-    def __repr__(self):
+    def __repr__(self):                 #pragma:nocover
         """Return a string representation of these connections."""
         attrs = sorted("%s = %r" % (k, v) for k, v in self.__dict__.iteritems() if not k.startswith("_"))
         return "%s(%s)" % (self.__class__.__name__, ", ".join(attrs))
