@@ -26,23 +26,23 @@ class TaskPlugin(Plugin, task.Task):
 
     implements(IWorkflowTask)
 
-    def __init__(self, *args, **kwds):
+    def __init__(self, *args, **kwds):      #pragma:nocover
         Plugin.__init__(self, *args, **kwds)
         task.Task.__init__(self, *args, **kwds)
 
     def __repr__(self):
-        return task.Task.__repr__(self)
+        return task.Task.__repr__(self)     #pragma:nocover
 
 
 class WorkflowPlugin(Plugin, workflow.Workflow):
 
     implements(IWorkflowTask)
 
-    def __init__(self, *args, **kwds):
+    def __init__(self, *args, **kwds):      #pragma:nocover
         Plugin.__init__(self, *args, **kwds)
         workflow.Workflow.__init__(self, *args, **kwds)
 
-    def __repr__(self):
+    def __repr__(self):                     #pragma:nocover
         return workflow.Workflow.__repr__(self)
 
 
@@ -58,7 +58,7 @@ class Selection_Task(TaskPlugin):
         #
         self.outputs.declare('selection')
 
-    def execute(self, *args, **kwds):
+    def execute(self):
         self.selection = self.data[self.index]
 
 
@@ -72,16 +72,13 @@ class Switch_Task(TaskPlugin):
         self.inputs.declare('value')
 
     def add_branch(self, value, task):
-        #print 'YY', repr(task)
         self._branches[value] = 'task'+str(task.id)
         self.output_controls.declare(self._branches[value])
 
         task.input_controls.declare('task'+str(self.id))
         setattr(task.input_controls, 'task'+str(self.id), self.output_controls[ self._branches[value] ])
-        #print 'YY', repr(task)
-        #print 'XX', type(self.output_controls[ self._branches[value] ])
 
-    def execute(self, *args, **kwds):
+    def execute(self):
         flag=False
         for key in self._branches:
             if self.value == key:
@@ -93,7 +90,7 @@ class Switch_Task(TaskPlugin):
             raise ValueError, "Branch condition has value '%s' but no branch is indexed with that value.\n    Valid branch indices: %s" % (str(self.value), sorted(self._branches.keys()))
 
     def __repr__(self):
-        return TaskPlugin.__repr__(self)
+        return TaskPlugin.__repr__(self)        #pragma:nocover
 
 
 class IfThen_Task(Switch_Task):
@@ -104,5 +101,5 @@ class IfThen_Task(Switch_Task):
         Switch_Task.__init__(self, *args, **kwds)
 
     def __repr__(self):
-        return Switch_Task.__repr__(self)
+        return Switch_Task.__repr__(self)       #pragma:nocover
 
